Florida's Second District Court of Appeal's Website

# July 02, 2014 2D13-61 / Smith v. State 2D13-1395 / Eveland v. State 2D13-3001 / Hunter v. State 2D13-4860 / Patterson v. State 2D13-5031 / Fox v. Sam Johnson, Chairman Polk County Commissioners
|  | Return Home / Search / Judges / Clerk's Office / Oral Arguments / Opinions Online Dockets / Using This Site & Plug-Ins / Privacy Policy / Accessibility All Content Copyright 2006 Second District Court of Appeal